==> gprs-converter-0.0.5-sources.jar: com/xdja/gprsconverter/protocol/EntryResponse.java <==
package com.xdja.gprsconverter.protocol;

import java.io.Serializable;
import java.util.List;

/**
 * 录入请求返回协议
 */

public class EntryResponse implements Serializable {
    /**
     * 版本
     */
    private String version;
    /**
     * 是否成功
     */
    private boolean isSuccess;
    /**
     * 失败或成功原因描述
     */
    private String message;
//    /**
//     * 不知道这个是干嘛用的，主键或者什么信息？
//     */
//    private List<ReturnItem> returnItemList;
//    /**
//     * 告警节点，后台配置了几个就有几个
//     */
//    private List<AlertInfo> alertInfoList;

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public boolean isSuccess() {
        return isSuccess;
    }

    public void setSuccess(boolean success) {
        isSuccess = success;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

//    public List<ReturnItem> getReturnItemList() {
//        return returnItemList;
//    }
//
//    public void setReturnItemList(List<ReturnItem> returnItemList) {
//        this.returnItemList = returnItemList;
//    }
//
//    public List<AlertInfo> getAlertInfoList() {
//        return alertInfoList;
//    }
//
//    public void setAlertInfoList(List<AlertInfo> alertInfoList) {
//        this.alertInfoList = alertInfoList;
//    }

    /**
     * 不知道干嘛用，暂时保留
     */
    public static class ReturnItem implements Serializable {
        private String key;
        private String value;

        public String getKey() {
            return key;
        }

        public void setKey(String key) {
            this.key = key;
        }

        public String getValue() {
            return value;
        }

        public void setValue(String value) {
            this.value = value;
        }
    }

    /**
     * 告警节点
     */
    public static class AlertInfo implements Serializable {
        /**
         * 请求类别
         */
        private String sort;
        /**
         * 对用中文名称
         */
        private String name;
        /**
         * 关联查询条件
         */
        private String condition;
        /**
         * 关联业务对应数据源
         */
        private String dbSource;
        /**
         * 如果为true，则alert字段内容为xml，否则为普通文字
         */
        private boolean isXML;
        /**
         * 报警信息
         */
        private String alert;

        public String getSort() {
            return sort;
        }

        public void setSort(String sort) {
            this.sort = sort;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public String getCondition() {
            return condition;
        }

        public void setCondition(String condition) {
            this.condition = condition;
        }

        public String getDbSource() {
            return dbSource;
        }

        public void setDbSource(String dbSource) {
            this.dbSource = dbSource;
        }

        public boolean isXML() {
            return isXML;
        }

        public void setXML(boolean XML) {
            isXML = XML;
        }

        public String getAlert() {
            return alert;
        }

        public void setAlert(String alert) {
            this.alert = alert;
        }
    }
}

==> gprs-converter-1.5.3-sources.jar: com/xdja/gprsconverter/protocol/EntryResponse.java <==
package com.xdja.gprsconverter.protocol;

import java.io.Serializable;
import java.util.List;

/**
 * 录入请求返回协议
 */

public class EntryResponse implements Serializable {
    /**
     * 版本
     */
    private String version;
    /**
     * 是否成功
     */
    private boolean isSuccess;
    /**
     * 失败或成功原因描述
     */
    private String message;

    private String response;
//    /**
//     * 不知道这个是干嘛用的，主键或者什么信息？
//     */
//    private List<ReturnItem> returnItemList;
//    /**
//     * 告警节点，后台配置了几个就有几个
//     */
//    private List<AlertInfo> alertInfoList;

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public boolean isSuccess() {
        return isSuccess;
    }

    public void setSuccess(boolean success) {
        isSuccess = success;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

//    public List<ReturnItem> getReturnItemList() {
//        return returnItemList;
//    }
//
//    public void setReturnItemList(List<ReturnItem> returnItemList) {
//        this.returnItemList = returnItemList;
//    }
//
//    public List<AlertInfo> getAlertInfoList() {
//        return alertInfoList;
//    }
//
//    public void setAlertInfoList(List<AlertInfo> alertInfoList) {
//        this.alertInfoList = alertInfoList;
//    }

    public String getResponse() {
        return response;
    }

    public void setResponse(String response) {
        this.response = response;
    }

    /**
     * 不知道干嘛用，暂时保留
     */
    public static class ReturnItem implements Serializable {
        private String key;
        private String value;

        public String getKey() {
            return key;
        }

        public void setKey(String key) {
            this.key = key;
        }

        public String getValue() {
            return value;
        }

        public void setValue(String value) {
            this.value = value;
        }
    }

    /**
     * 告警节点
     */
    public static class AlertInfo implements Serializable {
        /**
         * 请求类别
         */
        private String sort;
        /**
         * 对用中文名称
         */
        private String name;
        /**
         * 关联查询条件
         */
        private String condition;
        /**
         * 关联业务对应数据源
         */
        private String dbSource;
        /**
         * 如果为true，则alert字段内容为xml，否则为普通文字
         */
        private boolean isXML;
        /**
         * 报警信息
         */
        private String alert;

        public String getSort() {
            return sort;
        }

        public void setSort(String sort) {
            this.sort = sort;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public String getCondition() {
            return condition;
        }

        public void setCondition(String condition) {
            this.condition = condition;
        }

        public String getDbSource() {
            return dbSource;
        }

        public void setDbSource(String dbSource) {
            this.dbSource = dbSource;
        }

        public boolean isXML() {
            return isXML;
        }

        public void setXML(boolean XML) {
            isXML = XML;
        }

        public String getAlert() {
            return alert;
        }

        public void setAlert(String alert) {
            this.alert = alert;
        }
    }
}
